@@ -161,18 +161,35 @@ def test_astype(s, df):
 
     assert s.astype(str)[0] == "POINT (0 0)"
 
+    res = s.astype(object)
+    assert isinstance(res, pd.Series) and not isinstance(res, GeoSeries)
+    assert res.dtype == object
+
     df = df.rename_geometry("geom_list")
 
     # check whether returned object is a geodataframe
-    df = df.astype({"value1": float})
-    assert isinstance(df, GeoDataFrame)
+    res = df.astype({"value1": float})
+    assert isinstance(res, GeoDataFrame)
 
     # check whether returned object is a datafrane
-    df = df.astype(str)
-    assert isinstance(df, pd.DataFrame)
+    res = df.astype(str)
+    assert isinstance(res, pd.DataFrame) and not isinstance(res, GeoDataFrame)
 
-    df = df.astype({"geom_list": str})
-    assert isinstance(df, pd.DataFrame)
+    res = df.astype({"geom_list": str})
+    assert isinstance(res, pd.DataFrame) and not isinstance(res, GeoDataFrame)
+
+    res = df.astype(object)
+    assert isinstance(res, pd.DataFrame) and not isinstance(res, GeoDataFrame)
+    assert res["geom_list"].dtype == object
+
+
+def test_astype_invalid_geodataframe():
+    # https://github.com/geopandas/geopandas/issues/1144
+    # a GeoDataFrame without geometry column should not error in astype
+    df = GeoDataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
+    res = df.astype(object)
+    assert isinstance(res, pd.DataFrame) and not isinstance(res, GeoDataFrame)
+    assert res["a"].dtype == object
 
 
 def test_to_csv(df):
@@ -238,6 +255,11 @@ def test_fillna(s):
     res = s2.fillna(Point(1, 1))
     assert_geoseries_equal(res, s)
 
+    # allow np.nan although this does not change anything
+    # https://github.com/geopandas/geopandas/issues/1149
+    res = s2.fillna(np.nan)
+    assert_geoseries_equal(res, s2)
+
 
 def test_dropna():
     s2 = GeoSeries([Point(0, 0), None, Point(2, 2)])
